@@ -2,13 +2,20 @@ package Doodle::Grammar::Postgres;
 
 use 5.014;
 
-use Data::Object 'Class', 'Doodle::Library';
+use strict;
+use warnings;
+
+use registry 'Doodle::Library';
+use routines;
+
+use Data::Object::Class;
+use Data::Object::ClassHas;
 
 use Scalar::Util ();
 
 extends 'Doodle::Grammar';
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 has name => (
   def => 'postgres',
