@@ -2,9 +2,15 @@ package Doodle::Helpers;
 
 use 5.014;
 
-use Data::Object 'Role', 'Doodle::Library';
+use strict;
+use warnings;
 
-our $VERSION = '0.07'; # VERSION
+use registry 'Doodle::Library';
+use routines;
+
+use Data::Object::Role;
+
+our $VERSION = '0.08'; # VERSION
 
 # METHODS
 
@@ -13,7 +19,7 @@ method schema_create(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'create_schema');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -23,7 +29,7 @@ method schema_delete(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'delete_schema');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -33,7 +39,7 @@ method table_create(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'create_table');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -43,7 +49,7 @@ method table_delete(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'delete_table');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -53,7 +59,7 @@ method table_rename(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'rename_table');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -63,7 +69,7 @@ method column_create(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'create_column');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -73,7 +79,7 @@ method column_update(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'update_column');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -83,7 +89,7 @@ method column_rename(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'rename_column');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -93,7 +99,7 @@ method column_delete(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'delete_column');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -103,7 +109,7 @@ method index_create(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'create_index');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -113,7 +119,7 @@ method index_delete(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'delete_index');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -123,7 +129,7 @@ method relation_create(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'create_relation');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
@@ -133,7 +139,7 @@ method relation_delete(Any %args) {
 
   my $command = Doodle::Command->new(%args, name => 'delete_relation');
 
-  $self->commands->push($command);
+  push @{$self->commands}, $command;
 
   return $command;
 }
